==> aptechka-0.41.6.tgz: package/lib/controls/index.js <==
var V = (h) => {
  throw TypeError(h);
};
var S = (h, n, e) => n.has(h) || V("Cannot " + e);
var t = (h, n, e) => (S(h, n, "read from private field"), e ? e.call(h) : n.get(h)), s = (h, n, e) => n.has(h) ? V("Cannot add the same private member more than once") : n instanceof WeakSet ? n.add(h) : n.set(h, e), i = (h, n, e, a) => (S(h, n, "write to private field"), a ? a.call(h, e) : n.set(h, e), e), T = (h, n, e) => (S(h, n, "access private method"), e);
import { Notifier as G } from "../notifier/index.js";
import { i as o } from "../browser-0zX67oeU.js";
import { g as Q } from "../dom-0S_WDL4g.js";
import { ticker as k } from "../ticker/vanilla/index.js";
import "../Store-Cm3LPXlx.js";
import { a as J } from "../easings-BEmRlrDd.js";
import { T as Z } from "../Tweened-sqOQu9Gf.js";
import { s as $ } from "../gestures-D2Fdra_G.js";
import { p } from "../polyfills-CxfUK5OU.js";
import { TICK_ORDER as _ } from "../order/index.js";
var O;
class B {
  constructor() {
    s(this, O, new G());
  }
  get changeEvent() {
    return t(this, O);
  }
}
O = new WeakMap();
var w, d, f, P;
class fe extends B {
  constructor(e) {
    super();
    s(this, w, null);
    s(this, d, null);
    s(this, f, "offsetHeight");
    s(this, P, (e) => {
      const a = e.shiftKey ? -1 : 1;
      let r;
      e.code === "Space" ? r = a * t(this, d)[t(this, f)] * 0.4 : e.code === "ArrowLeft" ? r = -1 * t(this, d)[t(this, f)] * 0.2 : e.code === "ArrowRight" ? r = 1 * t(this, d)[t(this, f)] * 0.2 : e.code === "ArrowUp" ? r = -1 * t(this, d)[t(this, f)] * 0.2 : e.code === "ArrowDown" ? r = 1 * t(this, d)[t(this, f)] * 0.2 : e.code === "PageUp" ? r = -1 * t(this, d)[t(this, f)] : e.code === "PageDown" ? r = 1 * t(this, d)[t(this, f)] : e.code === "Home" ? r = 0 : e.code === "End" && (r = t(this, f) === "offsetWidth" ? t(this, d).scrollWidth : t(this, d).scrollHeight), r && (e.stopPropagation(), this.changeEvent.notify("keyboard", r));
    });
    o && (i(this, w, e != null && e.element && Q(e.element) || window), i(this, d, t(this, w) instanceof HTMLElement ? t(this, w) : document.documentElement), this.dimension = e == null ? void 0 : e.dimension);
  }
  set dimension(e) {
    i(this, f, e === "width" ? "offsetWidth" : "offsetHeight");
  }
  connect() {
    o && t(this, w).addEventListener(
      "keydown",
      t(this, P)
    );
  }
  disconnect() {
    o && t(this, w).removeEventListener(
      "keydown",
      t(this, P)
    );
  }
}
w = new WeakMap(), d = new WeakMap(), f = new WeakMap(), P = new WeakMap();
var g, x, X, Y, c, C, u, b, K, U, A, q, I;
class ue extends B {
  constructor(e) {
    super();
    s(this, b);
    s(this, g);
    s(this, x);
    s(this, X);
    s(this, Y);
    s(this, c);
    s(this, C);
    s(this, u);
    s(this, A);
    s(this, q);
    s(this, I);
    this.direction = 1, i(this, c, new Z(0, { easing: J })), i(this, u, !1), i(this, A, (a) => {
      t(this, c).current !== 1 && this.changeEvent.notify(
        "autoplay",
        a.timeBetweenFrames * t(this, g) * this.direction * (1 - t(this, c).current)
      );
    }), i(this, q, () => {
      t(this, c).current !== 1 && this.changeEvent.notify(
        "autoplay",
        Math.sign(t(this, g)) * this.direction * (1 - t(this, c).current)
      );
    }), i(this, I, () => {
      t(this, x) && (document.hidden ? t(this, c).set(1, { equalize: !0 }) : t(this, c).set(0, { equalize: !0 }));
    }), i(this, g, (e == null ? void 0 : e.speed) || 1), i(this, x, (e == null ? void 0 : e.interval) || !1), i(this, X, e);
  }
  set interval(e) {
    i(this, x, e), t(this, u) && T(this, b, K).call(this);
  }
  set speed(e) {
    i(this, g, e), t(this, u) && T(this, b, K).call(this);
  }
  connect() {
    t(this, u) || (i(this, u, !0), T(this, b, K).call(this));
  }
  disconnect() {
    t(this, u) && (i(this, u, !1), T(this, b, U).call(this));
  }
  pauseAndContinue(e, a) {
    t(this, u) && e && (clearTimeout(t(this, C)), t(this, c).set(1, {
      duration: Math.min(e, 1e3),
      equalize: a
    }), i(this, C, setTimeout(() => {
      t(this, c).set(0, {
        duration: Math.min(e, 5e3),
        equalize: a
      });
    }, e)));
  }
}
g = new WeakMap(), x = new WeakMap(), X = new WeakMap(), Y = new WeakMap(), c = new WeakMap(), C = new WeakMap(), u = new WeakMap(), b = new WeakSet(), K = function() {
  T(this, b, U).call(this), t(this, x) ? i(this, Y, setInterval(
    t(this, q),
    Math.abs(t(this, g))
  )) : k.subscribe(t(this, A), t(this, X)), document.addEventListener(
    "visibilitychange",
    t(this, I)
  );
}, U = function() {
  clearInterval(t(this, Y)), k.unsubscribe(t(this, A)), clearTimeout(t(this, C)), t(this, c).close(), document.removeEventListener(
    "visibilitychange",
    t(this, I)
  );
}, A = new WeakMap(), q = new WeakMap(), I = new WeakMap();
var D, v, H, N;
class me extends B {
  constructor(e) {
    super();
    s(this, D, null);
    s(this, v);
    s(this, H);
    s(this, N, (e) => {
      let a = 0;
      if (!(this.axis === "x" && Math.abs(e.deltaY) > Math.abs(e.deltaX) * 1 || this.axis === "y" && Math.abs(e.deltaX) > Math.abs(e.deltaY) * 1))
        if (e.preventDefault(), a = (this.axis === "max" ? Math.abs(e.deltaX) > Math.abs(e.deltaY) ? e.deltaX : e.deltaY : this.axis === "x" ? e.deltaX : e.deltaY) * this.speed, e.stopPropagation(), this.debounce) {
          const r = Date.now();
          if (r - t(this, H) > 40 && (a = 100 * Math.sign(a)), i(this, H, r), Math.abs(a) < 100 || t(this, v))
            return;
          this.changeEvent.notify("wheel", a), i(this, v, setTimeout(() => {
            i(this, v, void 0);
          }, 80));
        } else
          this.changeEvent.notify("wheel", a);
    });
    this.axis = (e == null ? void 0 : e.axis) || "y", this.speed = (e == null ? void 0 : e.speed) || 1, this.debounce = (e == null ? void 0 : e.debounce) || !1, i(this, H, Date.now()), o && i(this, D, e != null && e.element && Q(e.element) || window);
  }
  connect() {
    o && t(this, D).addEventListener(
      "wheel",
      t(this, N),
      {
        passive: !1
      }
    );
  }
  disconnect() {
    o && (t(this, D).removeEventListener(
      "wheel",
      t(this, N)
    ), clearTimeout(t(this, v)));
  }
}
D = new WeakMap(), v = new WeakMap(), H = new WeakMap(), N = new WeakMap();
var M, m, l, z, y;
const E = class E extends B {
  constructor(e) {
    super();
    s(this, m);
    s(this, l);
    s(this, z);
    s(this, y);
    this.inertion = 1, i(this, m, null), i(this, l, 0), i(this, z, (a) => {
      if (a.composedPath().find(
        (L) => L instanceof HTMLElement && L.hasAttribute("drag-dead-zone")
      ))
        return;
      this.swipe || k.unsubscribe(t(this, y));
      let r = a, F = !1;
      i(this, l, 0), document.documentElement.classList.add("grabbing");
      let R = 0, W = 0;
      $(
        (L) => {
          t(E, M) && t(E, M) !== t(this, m) || (R = r.x - L.x, W = r.y - L.y, this.axis === "x" ? i(this, l, R) : i(this, l, W), r = L, F = this.axis === "x" && Math.abs(R) > Math.abs(W) || this.axis === "y" && Math.abs(W) > Math.abs(R), F && (i(E, M, t(this, m)), this.changeEvent.notify("drag", t(this, l))));
        },
        () => {
          i(E, M, null), F && !this.swipe && this.inertion ? (i(this, l, t(this, l) * this.inertion), k.subscribe(t(this, y), {
            order: _.CONTROLS - 1
          })) : this.swipe && this.changeEvent.notify("drag-end", t(this, l)), document.documentElement.classList.remove("grabbing");
        }
      );
    }), i(this, y, () => {
      Math.floor(Math.abs(t(this, l))) || k.unsubscribe(t(this, y)), i(this, l, t(this, l) * 0.95), i(this, l, p(t(this, l), 3)), this.changeEvent.notify("drag", t(this, l));
    }), this.axis = (e == null ? void 0 : e.axis) || "y", this.swipe = (e == null ? void 0 : e.swipe) || !1, o && i(this, m, e != null && e.element && Q(e.element) || document.documentElement);
  }
  connect() {
    o && t(this, m).addEventListener("pointerdown", t(this, z));
  }
  disconnect() {
    o && (t(this, m).removeEventListener(
      "pointerdown",
      t(this, z)
    ), k.unsubscribe(t(this, y)));
  }
};
M = new WeakMap(), m = new WeakMap(), l = new WeakMap(), z = new WeakMap(), y = new WeakMap(), s(E, M, null);
let j = E;
export {
  ue as AutoplayControls,
  B as Controls,
  j as DragControls,
  fe as KeyboardControls,
  me as WheelControls
};

==> aptechka-0.42.1.tgz: package/lib/controls/index.js <==
var V = (h) => {
  throw TypeError(h);
};
var S = (h, n, e) => n.has(h) || V("Cannot " + e);
var t = (h, n, e) => (S(h, n, "read from private field"), e ? e.call(h) : n.get(h)), s = (h, n, e) => n.has(h) ? V("Cannot add the same private member more than once") : n instanceof WeakSet ? n.add(h) : n.set(h, e), i = (h, n, e, a) => (S(h, n, "write to private field"), a ? a.call(h, e) : n.set(h, e), e), T = (h, n, e) => (S(h, n, "access private method"), e);
import { Notifier as G } from "../notifier/index.js";
import { i as o } from "../browser-0zX67oeU.js";
import { g as Q } from "../dom-CVWzyXPH.js";
import { ticker as k } from "../ticker/index.js";
import "../Store-Cm3LPXlx.js";
import { b as J } from "../easings-Bni3YAAW.js";
import { T as Z } from "../Tweened-p5hYr6lL.js";
import { s as $ } from "../gestures-D2Fdra_G.js";
import { p } from "../polyfills-CxfUK5OU.js";
import { TICK_ORDER as _ } from "../order/index.js";
var O;
class B {
  constructor() {
    s(this, O, new G());
  }
  get changeEvent() {
    return t(this, O);
  }
}
O = new WeakMap();
var w, d, f, P;
class fe extends B {
  constructor(e) {
    super();
    s(this, w, null);
    s(this, d, null);
    s(this, f, "offsetHeight");
    s(this, P, (e) => {
      const a = e.shiftKey ? -1 : 1;
      let r;
      e.code === "Space" ? r = a * t(this, d)[t(this, f)] * 0.4 : e.code === "ArrowLeft" ? r = -1 * t(this, d)[t(this, f)] * 0.2 : e.code === "ArrowRight" ? r = 1 * t(this, d)[t(this, f)] * 0.2 : e.code === "ArrowUp" ? r = -1 * t(this, d)[t(this, f)] * 0.2 : e.code === "ArrowDown" ? r = 1 * t(this, d)[t(this, f)] * 0.2 : e.code === "PageUp" ? r = -1 * t(this, d)[t(this, f)] : e.code === "PageDown" ? r = 1 * t(this, d)[t(this, f)] : e.code === "Home" ? r = 0 : e.code === "End" && (r = t(this, f) === "offsetWidth" ? t(this, d).scrollWidth : t(this, d).scrollHeight), r && (e.stopPropagation(), this.changeEvent.notify("keyboard", r));
    });
    o && (i(this, w, e != null && e.element && Q(e.element) || window), i(this, d, t(this, w) instanceof HTMLElement ? t(this, w) : document.documentElement), this.dimension = e == null ? void 0 : e.dimension);
  }
  set dimension(e) {
    i(this, f, e === "width" ? "offsetWidth" : "offsetHeight");
  }
  connect() {
    o && t(this, w).addEventListener(
      "keydown",
      t(this, P)
    );
  }
  disconnect() {
    o && t(this, w).removeEventListener(
      "keydown",
      t(this, P)
    );
  }
}
w = new WeakMap(), d = new WeakMap(), f = new WeakMap(), P = new WeakMap();
var g, x, X, Y, c, C, u, b, K, U, A, q, I;
class ue extends B {
  constructor(e) {
    super();
    s(this, b);
    s(this, g);
    s(this, x);
    s(this, X);
    s(this, Y);
    s(this, c);
    s(this, C);
    s(this, u);
    s(this, A);
    s(this, q);
    s(this, I);
    this.direction = 1, i(this, c, new Z(0, { easing: J })), i(this, u, !1), i(this, A, (a) => {
      t(this, c).current !== 1 && this.changeEvent.notify(
        "autoplay",
        a.timeBetweenFrames * t(this, g) * this.direction * (1 - t(this, c).current)
      );
    }), i(this, q, () => {
      t(this, c).current !== 1 && this.changeEvent.notify(
        "autoplay",
        Math.sign(t(this, g)) * this.direction * (1 - t(this, c).current)
      );
    }), i(this, I, () => {
      t(this, x) && (document.hidden ? t(this, c).set(1, { equalize: !0 }) : t(this, c).set(0, { equalize: !0 }));
    }), i(this, g, (e == null ? void 0 : e.speed) || 1), i(this, x, (e == null ? void 0 : e.interval) || !1), i(this, X, e);
  }
  set interval(e) {
    i(this, x, e), t(this, u) && T(this, b, K).call(this);
  }
  set speed(e) {
    i(this, g, e), t(this, u) && T(this, b, K).call(this);
  }
  connect() {
    t(this, u) || (i(this, u, !0), T(this, b, K).call(this));
  }
  disconnect() {
    t(this, u) && (i(this, u, !1), T(this, b, U).call(this));
  }
  pauseAndContinue(e, a) {
    t(this, u) && e && (clearTimeout(t(this, C)), t(this, c).set(1, {
      duration: Math.min(e, 1e3),
      equalize: a
    }), i(this, C, setTimeout(() => {
      t(this, c).set(0, {
        duration: Math.min(e, 5e3),
        equalize: a
      });
    }, e)));
  }
}
g = new WeakMap(), x = new WeakMap(), X = new WeakMap(), Y = new WeakMap(), c = new WeakMap(), C = new WeakMap(), u = new WeakMap(), b = new WeakSet(), K = function() {
  T(this, b, U).call(this), t(this, x) ? i(this, Y, setInterval(
    t(this, q),
    Math.abs(t(this, g))
  )) : k.subscribe(t(this, A), t(this, X)), document.addEventListener(
    "visibilitychange",
    t(this, I)
  );
}, U = function() {
  clearInterval(t(this, Y)), k.unsubscribe(t(this, A)), clearTimeout(t(this, C)), t(this, c).close(), document.removeEventListener(
    "visibilitychange",
    t(this, I)
  );
}, A = new WeakMap(), q = new WeakMap(), I = new WeakMap();
var D, v, H, N;
class me extends B {
  constructor(e) {
    super();
    s(this, D, null);
    s(this, v);
    s(this, H);
    s(this, N, (e) => {
      let a = 0;
      if (!(this.axis === "x" && Math.abs(e.deltaY) > Math.abs(e.deltaX) * 1 || this.axis === "y" && Math.abs(e.deltaX) > Math.abs(e.deltaY) * 1))
        if (e.preventDefault(), a = (this.axis === "max" ? Math.abs(e.deltaX) > Math.abs(e.deltaY) ? e.deltaX : e.deltaY : this.axis === "x" ? e.deltaX : e.deltaY) * this.speed, e.stopPropagation(), this.debounce) {
          const r = Date.now();
          if (r - t(this, H) > 40 && (a = 100 * Math.sign(a)), i(this, H, r), Math.abs(a) < 100 || t(this, v))
            return;
          this.changeEvent.notify("wheel", a), i(this, v, setTimeout(() => {
            i(this, v, void 0);
          }, 80));
        } else
          this.changeEvent.notify("wheel", a);
    });
    this.axis = (e == null ? void 0 : e.axis) || "y", this.speed = (e == null ? void 0 : e.speed) || 1, this.debounce = (e == null ? void 0 : e.debounce) || !1, i(this, H, Date.now()), o && i(this, D, e != null && e.element && Q(e.element) || window);
  }
  connect() {
    o && t(this, D).addEventListener(
      "wheel",
      t(this, N),
      {
        passive: !1
      }
    );
  }
  disconnect() {
    o && (t(this, D).removeEventListener(
      "wheel",
      t(this, N)
    ), clearTimeout(t(this, v)));
  }
}
D = new WeakMap(), v = new WeakMap(), H = new WeakMap(), N = new WeakMap();
var M, m, l, z, y;
const E = class E extends B {
  constructor(e) {
    super();
    s(this, m);
    s(this, l);
    s(this, z);
    s(this, y);
    this.inertion = 1, i(this, m, null), i(this, l, 0), i(this, z, (a) => {
      if (a.composedPath().find(
        (L) => L instanceof HTMLElement && L.hasAttribute("drag-dead-zone")
      ))
        return;
      this.swipe || k.unsubscribe(t(this, y));
      let r = a, F = !1;
      i(this, l, 0), document.documentElement.classList.add("grabbing");
      let R = 0, W = 0;
      $(
        (L) => {
          t(E, M) && t(E, M) !== t(this, m) || (R = r.x - L.x, W = r.y - L.y, this.axis === "x" ? i(this, l, R) : i(this, l, W), r = L, F = this.axis === "x" && Math.abs(R) > Math.abs(W) || this.axis === "y" && Math.abs(W) > Math.abs(R), F && (i(E, M, t(this, m)), this.changeEvent.notify("drag", t(this, l))));
        },
        () => {
          i(E, M, null), F && !this.swipe && this.inertion ? (i(this, l, t(this, l) * this.inertion), k.subscribe(t(this, y), {
            order: _.CONTROLS - 1
          })) : this.swipe && this.changeEvent.notify("drag-end", t(this, l)), document.documentElement.classList.remove("grabbing");
        }
      );
    }), i(this, y, () => {
      Math.floor(Math.abs(t(this, l))) || k.unsubscribe(t(this, y)), i(this, l, t(this, l) * 0.95), i(this, l, p(t(this, l), 3)), this.changeEvent.notify("drag", t(this, l));
    }), this.axis = (e == null ? void 0 : e.axis) || "y", this.swipe = (e == null ? void 0 : e.swipe) || !1, o && i(this, m, e != null && e.element && Q(e.element) || document.documentElement);
  }
  connect() {
    o && t(this, m).addEventListener("pointerdown", t(this, z));
  }
  disconnect() {
    o && (t(this, m).removeEventListener(
      "pointerdown",
      t(this, z)
    ), k.unsubscribe(t(this, y)));
  }
};
M = new WeakMap(), m = new WeakMap(), l = new WeakMap(), z = new WeakMap(), y = new WeakMap(), s(E, M, null);
let j = E;
export {
  ue as AutoplayControls,
  B as Controls,
  j as DragControls,
  fe as KeyboardControls,
  me as WheelControls
};
